@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ocamlformat" "0.28.1"
+(define-package "ocamlformat" "20251024.1250"
   "Utility functions to format ocaml code."
   '((emacs "24.3"))
   :url "https://github.com/ocaml-ppx/ocamlformat"
   :commit "809492a6044557239ed1e1c2f78eec602f068ea4"
-  :revdesc "0.28.1-0-g809492a60445"
+  :revdesc "809492a60445"
   :keywords '("languages" "ocaml"))
